@@ -40,7 +40,7 @@ DCL::grsvpt(0.2,  0.8,   0.2,  0.8)
 DCL::grstrn(4)
 DCL::grstrf
 
-DCL::ussttl('FREQUENCY', '/s', 'POWER', 'm|2"/s|2"')
+DCL::ussttl('FREQUENCY', '/s', 'POWER', 'm\^2/s\^2')
 DCL::usdaxs
 
 DCL::uulin(x, y)
