@@ -40,7 +40,7 @@ DCL::sgtxzv(0.5, 0.95, cttl, 0.03, 0, 0, 3)
 for i in 0..255
   ux=i/16+0.5
   uy=16-(i.divmod(16))[1]-0.5
-  DCL::sgtxzu(ux, uy, DCL::csgi(i), 0.035, 0, 0, 3)
+  DCL::sgtxzu(ux, uy, DCL::usgi(i), 0.035, 0, 0, 3)
   ux=ux+0.48
   uy=uy+0.38
   ch = format("%3d", i)
