@@ -39,7 +39,7 @@ for n in 1..2
     ux=i/16+0.5
     uy=16-(i.divmod(16))[1]-0.5
     if (!(i == 30 || i == 31))
-      DCL::sgtxzu(ux, uy, DCL::csgi(i), 0.035, 0, 0, 3)
+      DCL::sgtxzu(ux, uy, DCL::usgi(i), 0.035, 0, 0, 3)
     end
     ux=ux+0.48
     uy=uy+0.38
