@@ -29,7 +29,7 @@ DCL::sgfrm
 DCL::sgswnd(-xmaxf/2.0, xmaxf/2.0, -ymaxf/2.0, ymaxf/2.0)
 DCL::sgstrf
 DCL::sgplu(x, y)
-DCL::sgtxzu(0.0, 0.0, "15cm #{DCL::csgi(194)} 15cm", 0.05, 0, 0, 3)
+DCL::sgtxzu(0.0, 0.0, "15cm #{DCL::usgi(194)} 15cm", 0.05, 0, 0, 3)
 
 DCL::sgcls
 
