@@ -71,9 +71,9 @@ DCL::uyaxlb('R', uy1, uy2, ch, nc)
 DCL::uysttl('L', 'LATITUDE', 0.0)
 
 DCL::uwsgxb(XMNZ, XMXZ, NXZ)
-DCL::uwsgya(uy1[(IYZ1-1)..-1])
+DCL::uwsgya(uy1[(IYZ1-1)..(IYZ1-1+NYZ-1)])
 
-DCL::udcntr(p[(IXZ1-1)..-1,(IYZ1-1)..-1])
+DCL::udcntr(p[(IXZ1-1)..(IXZ1-1+NXZ-1),(IYZ1-1)..(IYZ1-1+NYZ-1)])
 
 DCL::grcls
 
