@@ -35,7 +35,7 @@ DCL::gropn iws
 
 DCL::grfrm
 
-DCL::ussttl('TIME', 'SEC', 'HEAT FLUX', 'W/m|2"')
+DCL::ussttl('TIME', 'SEC', 'HEAT FLUX', 'W/m\^2')
 DCL::usgrph(t, a)
 
 DCL::grcls
