@@ -38,7 +38,7 @@ DCL::uscset('CYSPOS', 'B')
 DCL::uscset('CXSIDE', 'T')
 DCL::uscset('CYSIDE', 'L')
 
-DCL::ussttl('TEMPERATURE', 'C|'+ DCL::csgi(4) + '"', 'DEPTH', 'm')
+DCL::ussttl('TEMPERATURE', '\^'+ DCL::usgi(228) + 'C', 'DEPTH', 'm')
 DCL::usgrph(t, z)
 
 DCL::grcls
