@@ -80,7 +80,7 @@ tlevn.indgen(203.0, 3.0)
 cdsn = 'tomsclm.dat'
 file = open(cdsn, "r")
 
-DCL::swlstx('LWAIT', false)
+DCL::swlstx('LWAIT', true)
 DCL::swlstx('LWAIT0', false)
 DCL::swlstx('LDUMP', false)
 DCL::swistx('IPOSX', 200)
