@@ -20,8 +20,9 @@ y[0] = 0.5
 for n in 0..nmax-1
   y[n+1] = r*y[n]*(1.0-y[n])
 end
-yave = DCL::rave(y, nmax+1, 1)
-y = -4 * (y - yave)
+
+yave=DCL::rave(y,nmax+1,1)
+y =  -4 * (y - yave)
 
 #-- graph ---
 iws = (ARGV[0] || (puts ' WORKSTATION ID (I)  ? ;'; DCL::sgpwsn; gets)).to_i
@@ -45,7 +46,7 @@ DCL::uxsttl('B', 'YEAR', 0.0)
 
 DCL::uyaxdv('L', 0.1, 0.5)
 DCL::uyaxdv('R', 0.1, 0.5)
-cttl = DCL::csgi(131) + 'T [K]'
+cttl = DCL::usgi(131) + 'T [K]'
 DCL::uysttl('L', cttl, 0.0)
 
 DCL::uxmttl('T', 'INTERANNUAL VARIATION', 0.0)
