@@ -12,6 +12,8 @@ def aplot
   nmax = 40
   x = NArray.sfloat(nmax+1)
   y = NArray.sfloat(nmax+1)
+  xx = NArray.sfloat(4)
+  yy = NArray.sfloat(4)
 
   DCL::slpvpr(1)
 
@@ -27,11 +29,15 @@ def aplot
   #-- triangle ----
   dt = 2.0*PI/3
   for n in 0..3
-    x[n] = 40.0*sin(n*dt)
-    y[n] = 40.0*cos(n*dt)
+    xx[n] = 40.0*sin(n*dt)
+    yy[n] = 40.0*cos(n*dt)
   end
 
-  DCL::sgplu(x, y)
+  DCL::sgplu(xx, yy)
+
+p "OTB:"
+p xx
+p yy
 
   #-- string ----
   DCL::sgtxu(0.0, 0.0, 'SGTXU')
