@@ -31,15 +31,17 @@ end
 DCL::sglnv(xc, 0.05, xc, 0.95)
 
 #-- ǥե ----
-DCL::sgtxv(xc, y[0], 'SGTXV|SUP"RST_SUB"')
+DCL::sgtxv(xc, y[0], 'SGTXV\^{SUP}RST\_{SUB}')
 
 #-- ź ----
 DCL::sglset('LCNTL', true)
-DCL::sgtxv(xc, y[1], 'SGTXV|SUP"RST_SUB"')
+DCL::sgtxv(xc, y[1], 'SSGTXV\^{SUP}RST\_{SUB}')
 
 DCL::sgrset('SMALL', 0.5)
 DCL::sgrset('SHIFT', 0.5)
-DCL::sgtxv(xc, y[2], 'SGTXV|SUP"RST_SUB"')
+DCL::swlset('LSYSFNT', true)
+DCL::sgtxv(xc, y[2], 'S\o-G\o~T\u-X\o~\u-V\^{SUP}RST\_{SUB}')
+DCL::swlset('LSYSFNT', false)
 
 #-- ե ----
 DCL::sgtxv(xc, y[3], 'ABCDEFG abcdefg')
@@ -54,17 +56,17 @@ DCL::sgiset('IFONT', 1)
 DCL::sgstxi(1)
 
 #-- ꥷʸ ----
-greek1 = DCL::csgi(128) + DCL::csgi(129) + DCL::csgi(130) + DCL::csgi(131) + DCL::csgi(132) +
-         DCL::csgi(133) + DCL::csgi(134) + DCL::csgi(135) + DCL::csgi(136) + DCL::csgi(137)
-greek2 = DCL::csgi(152) + DCL::csgi(153) + DCL::csgi(154) + DCL::csgi(155) + DCL::csgi(156) +
-         DCL::csgi(157) + DCL::csgi(158) + DCL::csgi(159) + DCL::csgi(160) + DCL::csgi(161)
+greek1 = DCL::usgi(128) + DCL::usgi(129) + DCL::usgi(130) + DCL::usgi(131) + DCL::usgi(132) +
+         DCL::usgi(133) + DCL::usgi(134) + DCL::usgi(135) + DCL::usgi(136) + DCL::usgi(137)
+greek2 = DCL::usgi(152) + DCL::usgi(153) + DCL::usgi(154) + DCL::usgi(155) + DCL::usgi(156) +
+         DCL::usgi(157) + DCL::usgi(158) + DCL::usgi(159) + DCL::usgi(160) + DCL::usgi(161)
 
 DCL::sgtxv(xc, y[6], greek1)
 DCL::sgtxv(xc, y[7], greek2)
 
 #-- ü쵭 ----
-symbol = DCL::csgi(189) + DCL::csgi(190) + DCL::csgi(191) + DCL::csgi(192) + DCL::csgi(193) +
-         DCL::csgi(210) + DCL::csgi(211) + DCL::csgi(212) + DCL::csgi(217) + DCL::csgi(218)
+symbol = DCL::usgi(189) + DCL::usgi(190) + DCL::usgi(191) + DCL::usgi(192) + DCL::usgi(193) +
+         DCL::usgi(210) + DCL::usgi(211) + DCL::usgi(212) + DCL::usgi(217) + DCL::usgi(218)
 
 DCL::sgtxv(xc, y[8], symbol)
 
