@@ -27,7 +27,7 @@ DCL::gropn iws
 
 DCL::grfrm
 
-DCL::ussttl('TIME', 'YEAR', 'HEAT FLUX', 'W/m|2"')
+DCL::ussttl('TIME', 'YEAR', 'HEAT FLUX', 'W/m\^2')
 DCL::usgrph(x, y)
 
 DCL::grcls
