@@ -29,7 +29,7 @@ DCL::grfrm
 
 rundef = DCL::glrget('RUNDEF')
 DCL::grswnd(xmin, xmax, rundef, rundef)
-DCL::ussttl('TIME', 'YEAR', 'HEAT FLUX', 'W/m|2"')
+DCL::ussttl('TIME', 'YEAR', 'HEAT FLUX', 'W/m\^2')
 DCL::usgrph(rundef, y)
 
 DCL::grcls
