@@ -24,7 +24,11 @@ end
 case na_type
 when "narray"
   narray_include = File.expand_path(File.dirname(Gem.find_files("narray.h")[0]))
-  narray_lib = File.expand_path(File.dirname(Gem.find_files("narray." + so)[0]))
+  if `ruby -v`.include?("mingw")
+    narray_lib = File.expand_path(File.dirname(Gem.find_files("src/libnarray.a")[0]))
+  else
+    narray_lib = File.expand_path(File.dirname(Gem.find_files("narray." + so)[0]))
+  end
   File.open("../../lib/numru/dcl/narray_type.rb","w"){|f| f.puts <<EOS
 module NumRu
   module DCL
@@ -35,7 +39,11 @@ EOS
   }
 when "numru-narray"
   narray_include = File.expand_path(File.dirname(Gem.find_files("numru/narray/narray.h")[0]))
-  narray_lib = File.expand_path(File.dirname(Gem.find_files("numru/narray/narray." + so)[0]))
+  if `ruby -v`.include?("mingw")
+    narray_lib = File.expand_path(File.dirname(Gem.find_files("numru/narray/narray.a")[0]))
+  else
+    narray_lib = File.expand_path(File.dirname(Gem.find_files("numru/narray/narray." + so)[0]))
+  end
   File.open("../../lib/numru/dcl/narray_type.rb","w"){|f| f.puts <<EOS
 module NumRu
   module DCL
@@ -72,12 +80,20 @@ end
 initcfile_default = $srcdir+"/init.c.default"
 initcfile = $srcdir+"/init.c"
 
-if(xsystem("which cdclconfig"))
-  cflags = `cdclconfig --cflags`.gsub(/\n/, " ")
-  ldflags = `cdclconfig --ldflags`.gsub(/\n/, " ")
-  ldlibs = `cdclconfig --ldlibs`.gsub(/-R.*?\s/, " ").gsub(/\n/, " ")
-  print "checking DCL version... "
-  dclversion = `cdclconfig --dclversion`.strip
+if(xsystem("which dclconfig"))
+  if `ruby -v`.include?("mingw")
+    cflags = `sh dclconfig --cflags`.gsub(/\n/, " ")
+    ldflags = `sh dclconfig --ldflags`.gsub(/\n/, " ")
+    ldlibs = `sh dclconfig --ldlibs`.gsub(/-R.*?\s/, " ").gsub(/\n/, " ")
+    print "checking DCL version... "
+    dclversion = `sh dclconfig --dclversion`.strip
+  else
+    cflags = `dclconfig --cflags`.gsub(/\n/, " ")
+    ldflags = `dclconfig --ldflags`.gsub(/\n/, " ")
+    ldlibs = `dclconfig --ldlibs`.gsub(/-R.*?\s/, " ").gsub(/\n/, " ")
+    print "checking DCL version... "
+    dclversion = `dclconfig --dclversion`.strip
+  end
   print "DCL Version: #{dclversion}\n"
   dclver = dclversion.gsub(/\./,'')
   dclver = dclver+'0' if dclver.length <= 2   # 53 --> 530 etc
@@ -89,6 +105,9 @@ if(xsystem("which cdclconfig"))
   $CFLAGS += ' '+cflags  + dclversionmacro
   $LOCAL_LIBS += ' ' + ldflags
   $LOCAL_LIBS += ldlibs
+  if `ruby -v`.include?("mingw")
+    $LOCAL_LIBS += ldlibs + " -lnarray"
+  end
 
   fin = File.open(initcfile_default)
   fout = File.open(initcfile,'w')
@@ -99,7 +118,7 @@ if(xsystem("which cdclconfig"))
   fin.close
 
 else
-  raise "cdclconfig is not found."
+  raise "dclconfig is not found."
 end
 
 create_makefile("numru/dcl_raw")
